% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_census_tract.R
\name{read_census_tract}
\alias{read_census_tract}
\title{Download shape files of census tracts of the Brazilian Population Census (Only years 2000 and 2010 are currently available).}
\usage{
read_census_tract(code_tract, year = NULL, zone = "urban")
}
\arguments{
\item{code_tract}{The 7-digit code of a Municipality. If the two-digit code or a two-letter uppercase abbreviation of
a state is passed, (e.g. 33 or "RJ") the function will load all census tracts of that state. If code_tract="all",
all census tracts of the country are loaded.}

\item{year}{Year of the data (defaults to 2010)}

\item{zone}{"urban" or "rural" census tracts come in separate files in the year 2000 (defaults to "urban")}
}
\description{
Download shape files of census tracts of the Brazilian Population Census (Only years 2000 and 2010 are currently available).
}
\examples{
\donttest{

library(geobr)

# Read rural census tracts for years before 2007
  c <- read_census_tract(code_tract=5201108, year=2000, zone="rural")

# Read all census tracts of a state at a given year
  c <- read_census_tract(code_tract=53, year=2010); # or
  c <- read_census_tract(code_tract="DF", year=2010)
  plot(c)

# Read all census tracts of a municipality at a given year
  c <- read_census_tract(code_tract=5201108, year=2010)
  plot(c)

# Read all census tracts of the country at a given year
  c <- read_census_tract(code_tract="all", year=2010)

}




}
\seealso{
Other general area functions: \code{\link{read_amazon}},
  \code{\link{read_biomes}},
  \code{\link{read_conservation_units}},
  \code{\link{read_country}},
  \code{\link{read_immediate_region}},
  \code{\link{read_intermediate_region}},
  \code{\link{read_meso_region}},
  \code{\link{read_micro_region}},
  \code{\link{read_municipality}},
  \code{\link{read_region}}, \code{\link{read_semiarid}},
  \code{\link{read_state}},
  \code{\link{read_statistical_grid}},
  \code{\link{read_weighting_area}}
}
\concept{general area functions}
